/*

basic-setup.pov

2012 Samuel Benge

This scene shows how to use transformation include files exported from Blender.

The implementation given here is very basic. Objects other than boxes will need to be carefully rotated before the transformations are added to ensure proper orientation.

*/

#version 3.7;
 
//--- SCENE ---//

global_settings{
	assumed_gamma 1.0
	// use radiosity?
	#if(true)
		radiosity{
			error_bound 0.1
			count 256
			recursion_limit 1
			nearest_count 1
			pretrace_end .04/2
		}
	#end
}

#default{ finish{ambient 0} }

camera{
	location <0, 10, -5>
	look_at -y
	angle 50
}

background{srgb <.55, .5, .6>}

plane{y, 0 pigment{rgb 1}}

light_source{
	<1, .75, .8>*1e7,
	srgb 1.125*<1.5, 1.25, 1.0>
	// use area light?
	#if(true)
		#declare ALRes	= 3;
		#declare ALSize	= 0.03*1e7;
		area_light x*ALSize, z*ALSize, ALRes, ALRes
		jitter
		adaptive 1
	#end
}

// a texture for the boxes
#declare BoxTex =
	texture{
		pigment{
			granite
			turbulence .5
			lambda 3
			scale <1, 50, 1>
			poly_wave .25
			color_map{
				[0 rgb 0]
				[1 rgb <1, .8, .6>]
			}
		}
	}

// used when jittering the box texture
#declare Seed = seed(1001);


//--- DRAWING THE BOXES ---//

#include "shapes.inc"

// contains a 2D array of transformation vectors
#include "box_transforms.inc"

union{
	
	// looping through each object
	#for(V, 0, dimension_size(box_transforms, 1)-1)
		
		object{
			
			// using the scale vector to make a rounded box
			#local S = box_transforms[V][0];
			Round_Box_Union(-S, S, .025)
			
			// jittered texture
			texture{
				BoxTex
				translate 100*z*rand(Seed)
			}
			
			// rotating...
			rotate box_transforms[V][1]
			
			// translating...
			translate box_transforms[V][2]
		}
		
	#end
	
	// final corrective transformations
	scale <1, 1, -1>
	rotate x*90
}